@@ -344,6 +344,14 @@ class VPCSVM(BaseNode):
             return True
         return False
 
+    async def reset_console(self):
+        """
+        Reset console
+        """
+
+        if self.is_running():
+            await self.reset_wrap_console()
+
     @BaseNode.console_type.setter
     def console_type(self, new_console_type):
         """
